@@ -83,6 +83,28 @@ test_that("dsIsCompleted retrieves status of COMPLETED async command", {
   )
 })
 
+test_that("dsIsCompleted retrieves status of FAILED async command", {
+  result <- methods::new("ArmadilloResult",
+                         conn = connection,
+                         rval = list(result = NULL, async = TRUE)
+  )
+
+  content <- mock(list(status = "FAILED"))
+  get <- mock(content)
+
+  value <- with_mock(
+    "httr::GET" = get,
+    "httr::content" = content,
+    dsIsCompleted(result)
+  )
+
+  expect_equal(value, TRUE)
+  expect_args(get, 1,
+              handle = connection@handle,
+              path = "/lastcommand"
+  )
+})
+
 test_that("dsIsCompleted retrieves status of RUNNING async command", {
   result <- methods::new("ArmadilloResult",
     conn = connection,
